function [Gs, G, Sh, b] = greenf(x, plotflag)
%
%	FUNCTION [Gs, G, Sh] = GREENF(X, PlotFlag);    
%	
%	GREENF.M  calls  G0.M,  GPEAKS.M and BMWDATA.MAT to produce hydrodynamic
%	propagators (Green's functions) Gs, G, the organ of Corti shear operator Sh.
%	
%	X  = BM point vector covering interval 0-1 [def. X=(1:400)/400]
%	        PlotFlag = if set to 1, Green's functions plots are showed [def=0]
% 
%	Gs = Stapes-to-BM  Green's function (force generated by stapes acceleration
%	          and transmitted by fluid pressure field on a unit length BM segment).
%
%	G  = BM-to-BM Green's functions (force generated by the acceleration of
%	        a BM segment on the other BM segments,  (.*)-multiplied by integration
%	        differential vector dx).
%
%	Sh = sectional shear viscosity operator [= d../dx s(x) d../dx, where
%	         s(x) is the sectional shear viscosity of the organ of Corti assumed
%	         as viscous as water (needs multiplication by relative viscosity)]. 	
%
%	Unequally spaced X elements will be accepted also. 	
%	The unit dimension of Gs and G is Kg/BETA, that of Sh is 
%	Kg/(BETA*sec). BETA = 33.5 mm for the human cochlea.
%					
%	(R.Nobili-Padova University, F.Mammano-SISSA, rev. 22-11-97)

%   The density of water is 10^3 Kg/m^3. But lengths are expressed as
%   fractions of the cochlear duct length (33.5 mm). Let's call BETA
%   the unit length in our system. As 1 BETA = 33.5 x 10^{-3} meters
%   then 1 m = 29.85 BETA. So we can express the density of water 
%   in our system as: rho=1000/(29.85)^3 Kg/BETA^3
%
%   Author: Renato Nobili - Padova University, Italy (October 2000)
%


if nargin < 2
	plotflag=0;
end
if nargin < 1
	plotflag=1;
    x = (1:400)/400;
end


N =length(x);           

rho = 0.0376;	% = 1000/(29.85)^3 Kg/BETA^3 

disp('	Computing coarse Green''s functions ...');

[Gs, G]=g0(x, plotflag);		% unshaped coarse profile of the Green's function 

bmwdata = [];		% array initialisation: bmwdata(:,1)=abscissae,
			                    % bmwdata(:,2)=ordinates
 
load bmwdata.mat -ascii	% Loading BM-width data from ascii *.mat file

%bmwdata(:,2) = [bmwdata(1:10,2); 7.3e-3; 7.8e-3; 7.9e-3; 7.95e-3; 8.0e-3; 8.05e-3; 8.05e-3; 8.05e-3; 8.05e-3; 8.05e-3; ones(7,1)*8.05e-3 ];

% bmwdata(:,2) = [bmwdata(1:10,2); 7.4e-3; 7.8e-3; 7.9e-3; 8e-3; 8.1e-3; 8.2e-3; 8.3e-3; 8.4e-3; 8.5e-3; 8.6e-3; (8.7:0.1:9.3)'*1e-3];


b= interpol(bmwdata(:,1),bmwdata(:,2), x); % Interpolating BM-width data

b=b/2;	% On account of radial BM curvature, the effective BM width is assumed  geometric-width/2

b=b(:);


disp('	Building Green''s function peaks ...')
time=clock;
[P, dx] = gpeaks(x, plotflag);	
                                        % dx is a column representing the differentials of
			                            % the fractional distance from stapes x, for general spacing.  
			                            % P = unshaped singular part of Green's function
			                            % times integration differential factors dx. 
			                            % P is computed as the differential after x of a 
			                             % symmetric sigmoidal function (see GPEAKS.M)

disp(['	CPU time taken by GPEAKS: ', num2str(etime(clock,time)),' sec']);

u=ones(size(dx));

disp('	Computing Green''s functions ...');

% dx is returned by GPEAKS as a column 

G=G.*(u*dx') +0.5*P;   % matrix  dx*u' is the Kronecker product of unit   
		                                % vector u by the integration differential array dx
    	                                % providing G with integration differential factors
		                                % (already accounted for in P). Here G is adimensional 
                                        % Peaks are reduced by 1/2 in this version (circular scalae corss section)

% Po=0.5*P(1,:);                                                                     
% B=zeros(size(P));       % uncomment this to add peak reflection at the BM base (no appreciable effect) 
% for n=1:N,
%     B(n, 1:(N+1-n)) = Po(n:N);
% end    
%     
% G=G+B;
% 
% if plotflag,
%     figure(10)
%     clf
%     plot(x, B(1:10, :))
%     title('Peaks at base');
%     pause(5)
% end
              
% b = ones(size(b))*3e-3; % chnage width of the BM in order to change Green functions
% 1.3.14 Vencovsky
G= G.*(b*(rho*b'));  % Matrix form factor on account of the BM width and 
		                           % water density. Unit dimension of G is Kg/BETA
% moje uprava    
% mM = max(max(b*(rho*b')));
% mnasob = mM*ones(size(b*(rho*b')));
% G=G.*mnasob;  % Matrix form factor on account of the BM width and 
		                           % water density. Unit dimension of G is Kg/BETA                                   
		                                      
S=3.2/33.5^2;    %  Area of  human stapes footplate in BETA units (3.2 mm^2 according to Aibara et al. (2000))   
S = S/2;               %  Effective area is 1/2th as footplate rocks and inflects.   
                         
Gs=(rho*S*b').*Gs;		

disp('	Computing sectional shear viscosity operator ...');


invdx=u./dx;		% inverse differentials

Der=diag(invdx,0);
Derr = Der-diag(invdx(2:N),-1);  % First derivative at right.
				   					                     % Unit dimension = 1/BETA
Derl = Der-diag(invdx(1:N-1),1); % First derivative at left.
				                                          % Unit dimension = 1/BETA

x=x(:);

% --------------- Shear viscosity computations -----------------------------

micron = 29.85e-6;  % 1 micron in BETA

h0 = 20*micron;	      %   40 micron,  
% 		                          %  putative height of the organ of Corti at base
% 		                          %  (effective for shear viscosity) 

% h = h0*exp(log(5)*x.^1.2);	% effective organ of Corti thickness (increases by 4 from base to apex)
h =  h0*exp(log(4)*x); % default

w0 = 50*micron;	  % 50 micron, mean radial width of the organ of Corti at base
		 			             % (effective for shear viscosity) 

w = w0*exp(log(4)*x); % effective organ of Corti radial width (increases by 4 from base to apex)

eta = 1e-3/29.85; %  Kg/(BETA*sec) 
					            % 10^{-3} Kg/(m*sec) = viscosity coefficient of water
					            % at 20 Celsius degrees (very close to 1 centipoise)	

s = eta*w.*h; 	  % Sectional shear viscosity constant, assuming that
					        % adjacent sectional segments of the organ of Corti
					        % are viscous like water. Unit dimension of s is Kg*BETA/sec
% ----------------------------------------------------------------------------	

Sh = Derl*diag(s)*Derr; % sectional shear viscosity operator
                                            % Unit dimension of Sh is Kg/(BETA*sec) 

%%%%%%%%%%%%%  PLOTS %%%%%%%%%%%%%%%%%%%
if plotflag==1,
	BETA=0.0335; % BM length in meters
	DX=BETA/N;     % dx length in meters. As G is in Kg/BETA, G/dx is in Kg/BETA^2  
	Gfactor=1/(DX*BETA); 
	figure(6)
	subplot(211), 
	plot(x, G(1:20:N, :)*Gfactor,'k-'),
	title('Samples of BM-BM Green''s function [Kg/m^2]', 'Interpreter', 'tex'),
	subplot(212),
	plot(x, Gs/BETA, 'k-'),
	title('Stapes-BM fluid coupling  [Kg/m]')
	xlabel('Fractional distance from stapes');
end